==> magpie-data-0.9.1-sources.jar: io/openraven/magpie/data/aws/rds/RDSInstance.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.rds;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.rds.model.DBInstance;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = RDSInstance.TABLE_NAME)
public class RDSInstance extends AWSResource {

  protected static final String TABLE_NAME = "awsrdsdbinstance";
  public static final String RESOURCE_TYPE = "AWS::RDS::DBInstance";

  @SuppressWarnings("unused")
  public RDSInstance() {
    this.resourceType = RESOURCE_TYPE;
  }


  public RDSInstance(String account, String regionId, DBInstance resource) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = resource.dbInstanceArn();
    this.resourceId = resource.dbInstanceArn();
    this.resourceName = resource.dbInstanceIdentifier();
    this.resourceType = RESOURCE_TYPE;
    this.configuration = PayloadUtils.update(resource);
    this.createdIso = resource.instanceCreateTime();
  }

}

==> magpie-data-0.11.6-sources.jar: io/openraven/magpie/data/aws/rds/RDSInstance.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.rds;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.rds.model.DBInstance;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = RDSInstance.TABLE_NAME)
public class RDSInstance extends AWSResource {

  protected static final String TABLE_NAME = "awsrdsdbinstance";
  public static final String RESOURCE_TYPE = "AWS::RDS::DBInstance";

  @SuppressWarnings("unused")
  public RDSInstance() {
    this.resourceType = RESOURCE_TYPE;
  }


  public RDSInstance(String account, String regionId, DBInstance resource) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = resource.dbInstanceArn();
    this.resourceId = resource.dbInstanceArn();
    this.resourceName = resource.dbInstanceIdentifier();
    this.resourceType = RESOURCE_TYPE;
    this.configuration = PayloadUtils.update(resource);
    this.createdIso = resource.instanceCreateTime();
  }

}
